nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Intsetstat

Struct Intsetstat 

#[repr(transparent)]
pub struct Intsetstat(pub u32);
USB set interrupt status register

Tuple Fields

0: u32

Implementations

Source

impl Intsetstat

pub const fn ep_set_int(&self) -> u16

If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.

pub const fn set_ep_set_int(&mut self, val: u16)

If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.

pub const fn frame_set_int(&self) -> bool

If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.

pub const fn set_frame_set_int(&mut self, val: bool)

If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.

pub const fn dev_set_int(&self) -> bool

If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.

pub const fn set_dev_set_int(&mut self, val: bool)

If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.