#[repr(transparent)]pub struct Lpm(pub u32);Expand description
USB Link Power Management register
Tuple Fields
0: u32Implementations
Sourceimpl Lpm
impl Lpm
Sourcepub const fn set_hird_hw(&mut self, val: u8)
pub const fn set_hird_hw(&mut self, val: u8)
Host Initiated Resume Duration - HW.
Sourcepub const fn set_hird_sw(&mut self, val: u8)
pub const fn set_hird_sw(&mut self, val: u8)
Host Initiated Resume Duration - SW.
Sourcepub const fn data_pending(&self) -> bool
pub const fn data_pending(&self) -> bool
As long as this bit is set to one and LPM supported bit is set to one, HW will return a NYET handshake on every LPM token it receives.
Sourcepub const fn set_data_pending(&mut self, val: bool)
pub const fn set_data_pending(&mut self, val: bool)
As long as this bit is set to one and LPM supported bit is set to one, HW will return a NYET handshake on every LPM token it receives.