#[repr(transparent)]pub struct Intsetstat(pub u32);Expand description
USB set interrupt status register
Tuple Fields
0: u32Implementations
Sourceimpl Intsetstat
impl Intsetstat
Sourcepub const fn ep_set_int(&self) -> u16
pub const fn ep_set_int(&self) -> u16
If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.
Sourcepub const fn set_ep_set_int(&mut self, val: u16)
pub const fn set_ep_set_int(&mut self, val: u16)
If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.
Sourcepub const fn frame_set_int(&self) -> bool
pub const fn frame_set_int(&self) -> bool
If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.
Sourcepub const fn set_frame_set_int(&mut self, val: bool)
pub const fn set_frame_set_int(&mut self, val: bool)
If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.
Sourcepub const fn dev_set_int(&self) -> bool
pub const fn dev_set_int(&self) -> bool
If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.
Sourcepub const fn set_dev_set_int(&mut self, val: bool)
pub const fn set_dev_set_int(&mut self, val: bool)
If software writes a one to one of these bits, the corresponding USB interrupt status bit is set.